timespantools.offset_happens_before_timespan_stops
==================================================

.. autofunction:: abjad.tools.timespantools.offset_happens_before_timespan_stops.offset_happens_before_timespan_stops
